;; Generated package description from diff-hl.el  -*- no-byte-compile: t -*-
(define-package "diff-hl" "1.8.8.0.20220816.191522" "Highlight uncommitted changes using VC" '((cl-lib "0.2") (emacs "25.1")) :commit "283aa2b9df68ed125090d66a0ae664e1fc196b74" :authors '(("Dmitry Gutov" . "dgutov@yandex.ru")) :maintainer '("Dmitry Gutov" . "dgutov@yandex.ru") :keywords '("vc" "diff") :url "https://github.com/dgutov/diff-hl")
